Machine Translation — Pootle 2.7.6 documentation

# Machine Translation

Pootle has the ability to use online Machine Translation (MT) Services to give suggestions to translators. This feature has to be enabled by the server administrators.

## Using Machine Translation

Note

Machine Translations are not meant to replace human translations but to give a general idea or understanding of the source text. It can be used as suggestion of a translation, but don’t forget to review the suggestion given.

If the server administrator has enabled machine translation then an icon will be displayed for each source text (English or alternative source language) next to the Copy button. Clicking the relevant buttons will retrieve translation suggestions from the online services and will mark the current string as fuzzy to indicate that review is required.

## Enabling Machine Translations

To enable a certain Machine Translation Service, edit your configuration file and add the desired service within the `POOTLE_MT_BACKENDS` setting.

Each line is a tuple which has the name of the service and an optional API key. Some services may not require API keys but others do, so please take care of getting an API key when necessary.

## Available Machine Translation Services

Supported Services:

Google Translate

Yandex.Translate

New in version 2.7: Yandex.Translate

Google Translate is widely used and supports a number of languages. It is a paid service requiring an account and API key.

Yandex.Translate is the free alternative to Google.